ytree\.arbor\.frontends\.rockstar\.fields\.RockstarFieldInfo
============================================================

.. currentmodule:: ytree.arbor.frontends.rockstar.fields

.. autoclass:: RockstarFieldInfo

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RockstarFieldInfo.__init__
      ~RockstarFieldInfo.clear
      ~RockstarFieldInfo.copy
      ~RockstarFieldInfo.fromkeys
      ~RockstarFieldInfo.get
      ~RockstarFieldInfo.items
      ~RockstarFieldInfo.keys
      ~RockstarFieldInfo.pop
      ~RockstarFieldInfo.popitem
      ~RockstarFieldInfo.resolve_field_dependencies
      ~RockstarFieldInfo.setdefault
      ~RockstarFieldInfo.setup_aliases
      ~RockstarFieldInfo.setup_derived_fields
      ~RockstarFieldInfo.update
      ~RockstarFieldInfo.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~RockstarFieldInfo.alias_fields
   
   